Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(203)

Unified Diff: net/http/transport_security_persister.h

Issue 511163002: Net-related fixups for scoped_refptr conversion operator cleanup. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix naming to match Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/disk_cache/simple/simple_index.cc ('k') | net/http/transport_security_persister.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/http/transport_security_persister.h
diff --git a/net/http/transport_security_persister.h b/net/http/transport_security_persister.h
index 7725ba124e603b19fd74c0181ebd5a655a4ce305..79a0d7a1aa9e6856c891c56f58d17843fe900332 100644
--- a/net/http/transport_security_persister.h
+++ b/net/http/transport_security_persister.h
@@ -13,7 +13,7 @@
// This means that it's possible for pages opened very quickly not to get the
// correct transport security information.
//
// To load the state, we schedule a Task on file_task_runner, which
// deserializes and configures the TransportSecurityState.
//
// The TransportSecurityState object supports running a callback function
@@ -51,16 +51,17 @@ namespace net {
// Reads and updates on-disk TransportSecurity state. Clients of this class
// should create, destroy, and call into it from one thread.
//
// file_task_runner is the task runner this class should use internally to
// perform file IO, and can optionally be associated with a different thread.
class NET_EXPORT TransportSecurityPersister
: public TransportSecurityState::Delegate,
public base::ImportantFileWriter::DataSerializer {
public:
- TransportSecurityPersister(TransportSecurityState* state,
- const base::FilePath& profile_path,
- base::SequencedTaskRunner* file_task_runner,
- bool readonly);
+ TransportSecurityPersister(
+ TransportSecurityState* state,
+ const base::FilePath& profile_path,
+ const scoped_refptr<base::SequencedTaskRunner>& background_runner,
+ bool readonly);
virtual ~TransportSecurityPersister();
// Called by the TransportSecurityState when it changes its state.
« no previous file with comments | « net/disk_cache/simple/simple_index.cc ('k') | net/http/transport_security_persister.cc » ('j') | no next file with comments »
@@ -13,7 +13,7 @@
// correct transport security information.
//
-// To load the state, we schedule a Task on file_task_runner, which
+// To load the state, we schedule a Task on background_runner, which
// deserializes and configures the TransportSecurityState.
//
@@ -51,16 +51,17 @@ namespace net {
// should create, destroy, and call into it from one thread.
//
-// file_task_runner is the task runner this class should use internally to
+// background_runner is the task runner this class should use internally to
// perform file IO, and can optionally be associated with a different thread.
class NET_EXPORT TransportSecurityPersister

Powered by Google App Engine
This is Rietveld 408576698